@@ -13,30 +13,9 @@ package inc::MBX::Alien::FLTK::Platform::Unix::Solaris;
     sub configure {
         my ($self) = @_;
         $self->SUPER::configure() || return 0;    # Get basic config data
-
-        # cpantesters.org/cpan/report/07134937-b19f-3f77-b713-d32bba55d77f
-        $self->notes('define')->{'HAVE_SCANDIR'}    # STR #1890
-            = $self->notes('os_ver') =~ '510' ? 1 : 0;    # 5.10 has scandir
+        $self->notes('define')->{'HAVE_SCANDIR'} = undef;
         return 1;
     }
-
-    sub _configure_ar {
-        my $s = shift;
-        print 'Locating library archiver... ';
-        open(my ($OLDOUT), ">&STDOUT");
-        close *STDOUT;
-        my ($ar) = grep { defined $_ } can_run($Config{'gar'}),
-            can_run($Config{'ar'});
-        open(*STDOUT, '>&', $OLDOUT)
-            || exit !print "Couldn't restore STDOUT: $!\n";
-        if (!$ar) {
-            print "Could not find the library archiver, aborting.\n";
-            exit 0;
-        }
-        $ar .= ' -r -c' . (can_run($Config{'ranlib'}) ? ' -s' : '');
-        $s->notes(AR => $ar);
-        print "$ar\n";
-    }
     1;
 }
 
