@@ -3,14 +3,13 @@ package Alien::FLTK2;
     use strict;
     use warnings;
     use File::Spec::Functions qw[catdir rel2abs canonpath];
-    our $BASE = 0; our $SVN = 9296; our $DEV = 0; our $VERSION = sprintf('%d.%05d' . ($DEV ? (($DEV < 0 ? '' : '_') . '%03d') : ('')), $BASE, $SVN, abs $DEV);
+    our $BASE = 0; our $SVN = 6970; our $DEV = -16; our $VERSION = sprintf('%d.%05d' . ($DEV ? (($DEV < 0 ? '' : '_') . '%03d') : ('')), $BASE, $SVN, abs $DEV);
 
     sub _md5 {
-        return {bz2 => 'd4d62c0ec8f33881c05217d9b487da2d',
-                gz  => '37ee9b6faec0e6b15f1833af798642cf'
+        return {gz  => '8159cabebbd1b5b774b277827aa4e030',
+                bz2 => 'f78976d0ba1a5c845e14f4df96d580a0'
         };
     }
-
     sub _unique_file { return 'src/Widget.cxx' }
 
     sub new {
@@ -21,8 +20,8 @@ package Alien::FLTK2;
             ($self->{'basedir'})
                 = (grep { -d $_ && -f catdir($_, 'config.yml') }
                        map { rel2abs($_) } (
-                        'share', '../share', '../../share',
-                        eval { File::ShareDir::dist_dir('Alien-FLTK2') }
+                             eval { File::ShareDir::dist_dir('Alien-FLTK2') },
+                             'share', '../share', '../../share'
                        )
                 );
         }
@@ -62,20 +61,19 @@ package Alien::FLTK2;
 
     sub ldflags {    # XXX - Cache this
         my ($self, @args) = @_;
-        my $MSVC = 'Windows|MSVC' eq join '|', @{$self->config->{'platform'}};
 
         #
         my $libdir = shift->library_path();
 
         # Calculate needed libraries
         my $SHAREDSUFFIX
-            = $self->config->{'_a'}
-            ? $self->config->{'_a'}
-            : $^O =~ '$MSWin32' ? '.a'    # Even on MSVC... for now.
+            = $self->config->{'_a'} ? $self->config->{'_a'}
+            : $^O =~ '$MSWin32' ? '.a'
             :                     '.o';
-        my $LDSTATIC = sprintf '%s/libfltk2%s %s', $libdir, $SHAREDSUFFIX,
+        my $LDSTATIC = sprintf '-L%s %s/libfltk2%s %s', $libdir, $libdir,
+            $SHAREDSUFFIX,
             ($self->config->{'ldflags'} ? $self->config->{'ldflags'} : '');
-        my $LDFLAGS = '-lfltk2 '
+        my $LDFLAGS = '-lfltk2'
             . ($self->config->{'ldflags'} ? $self->config->{'ldflags'} : '');
         my $LIBS = sprintf '%s/libfltk2%s', $libdir, $SHAREDSUFFIX;
         if (grep {m[forms]} @args) {
@@ -100,16 +98,9 @@ package Alien::FLTK2;
             $LDSTATIC = sprintf '%s/libfltk2_images%s %s %s',
                 $libdir, $SHAREDSUFFIX, $img_libs, $LDSTATIC;
         }
-        my $ret
-            = (  " -L$libdir "
-               . (($MSVC || grep {m[static]} @args) ? $LDSTATIC : $LDFLAGS)
-               . ($MSVC ? '' : ' -lsupc++'));
-        if ($MSVC) {    # Oy...
-            $ret =~ s[-L([^\s]*)][/libpath:"$1"]g;
-            $ret =~ s[-l([^\s]*)][$1]g;
-            $ret =~ s[-D([^\s]+)][/D"$1"]g;
-        }
-        return $ret;
+        return (  "-L$libdir "
+                . ((grep {m[static]} @args) ? $LDSTATIC : $LDFLAGS)
+                . ' -lsupc++');
     }
 
     sub capabilities {
@@ -127,7 +118,7 @@ package Alien::FLTK2;
 
 =head1 NAME
 
-Alien::FLTK2 - Build and use the experimental 2.0.x branch Fast Light Toolkit
+Alien::FLTK2 - Build and use the experimental C<2.0.x> branch Fast Light Toolkit
 
 =head1 Description
 
@@ -223,8 +214,8 @@ arguments are:
 
 Returns flags to link against a static FLTK library.
 
-FLTK's license allows static linking, but L<Alien::FLTK2|Alien::FLTK2> does
-not build static libs. ...yet.
+FLTK's license allows static linking, but L<Alien::FLTK2|Alien::FLTK2> does not
+build static libs. ...yet.
 
 =item C<gl>
 
@@ -290,20 +281,17 @@ Prerequisites differ by system...
 
 =item Win32
 
-The fltk2 libs and L<Alien::FLTK2|Alien::FLTK2> both build right out of the
-box with MinGW. Further testing is needed for other setups.
+The fltk2 libs and L<Alien::FLTK2|Alien::FLTK2> both build right out of the box
+with MinGW. Further testing is needed for other setups.
 
 =item X11/*nix
 
 X11-based systems require several development packages. On Debian, these may
-be installed with:
+be installed with...
 
-    > sudo apt-get install libx11-dev
-    > sudo apt-get install libxi-dev
-
-Additionally, the optional XCurser lib may be installed with:
-
-    > sudo apt-get install libxcursor-dev
+  > sudo apt-get install libx11-dev
+  > sudo apt-get install libxi-dev
+  > sudo apt-get install libxcursor-dev
 
 =item Darwin/OSX
 
@@ -330,7 +318,7 @@ following procedure:
 http://github.com/sanko/alien-fltk/issues
 
 Please only report L<Alien::FLTK2|Alien::FLTK2> related bugs to this tracker.
-For L<FLTK|FLTK> issues, use http://github.com/sanko/fltk-perl2/issues/
+For L<FLTK|FLTK> issues, use http://github.com/sanko/fltk-perl/issues/
 
 =item * Commit Log
 
@@ -354,13 +342,13 @@ for L<Alien::FLTK2|Alien::FLTK2> too.
 
 =item * Repository
 
-http://github.com/sanko/alien-fltk2/ and you are invited to fork it.
+http://github.com/sanko/alien-fltk/ and you are invited to fork it.
 
 =back
 
 =head2 Examples
 
-Please see the L<Synopsis|Alien::FLTK2/"Synopsis"> and the files in the C</examples/>.
+Please see the L<Synopsis|/"Synopsis"> and the files in the C</examples/>.
 
 =head2 Bugs
 
@@ -390,7 +378,7 @@ CPAN ID: SANKO
 
 =head1 License and Legal
 
-Copyright (C) 2009-2011 by Sanko Robinson E<lt>sanko@cpan.orgE<gt>
+Copyright (C) 2009 by Sanko Robinson E<lt>sanko@cpan.orgE<gt>
 
 This program is free software; you can redistribute it and/or modify it under
 the terms of The Artistic License 2.0. See the F<LICENSE> file included with
@@ -405,6 +393,6 @@ clarification, see http://creativecommons.org/licenses/by-sa/3.0/us/.
 L<Alien::FLTK2|Alien::FLTK2> is based in part on the work of the FLTK project.
 See http://www.fltk.org/.
 
-=for git $Id: FLTK2.pm df17165 2012-01-24 17:46:38Z sanko@cpan.org $
+=for git $Id: FLTK2.pm 449ae6a 2010-02-09 21:02:29Z sanko@cpan.org $
 
 =cut
